@@ -28,6 +28,9 @@
 #![feature(const_deref)]
 #![feature(const_intrinsic_copy)]
 #![feature(const_maybe_uninit_as_mut_ptr)]
+#![feature(const_ptr_offset)]
+#![feature(const_ptr_read)]
+#![feature(const_ptr_write)]
 #![feature(const_refs_to_cell)]
 #![feature(const_slice_from_raw_parts)]
 #![feature(const_slice_ptr_len)]
